@@ -7,8 +7,14 @@ from typing import Literal
 
 import keyring
 import yaml
-from pydantic import EmailStr, computed_field
-from pydantic_settings import BaseSettings, SettingsConfigDict
+from keyring.errors import NoKeyringError
+from pydantic import computed_field
+from pydantic_settings import (
+    BaseSettings,
+    PydanticBaseSettingsSource,
+    SettingsConfigDict,
+    YamlConfigSettingsSource,
+)
 
 
 def get_env() -> Literal["local", "staging", "production"]:
@@ -21,9 +27,9 @@ def set_env(name: Literal["local", "staging", "production"]) -> None:
     os.environ[f"{__package__.upper()}_ENV"] = name
 
 
-def get_env_suffix() -> str:
+def get_env_suffix(sep: str = "-") -> str:
     if get_env() != "production":
-        return "-" + get_env()
+        return sep + get_env()
     return ""
 
 
@@ -39,16 +45,36 @@ class Settings(BaseSettings):
             f"config{get_env_suffix()}.yaml",
         ),
         extra="ignore",
+        env_prefix="CALKIT" + get_env_suffix(sep="_") + "_",
     )
-    username: EmailStr | None = None
+    username: str | None = None
+    email: str | None = None
     token: str | None = None
     dvc_token: str | None = None
     dataframe_engine: Literal["pandas", "polars"] = "pandas"
 
+    @classmethod
+    def settings_customise_sources(
+        cls,
+        settings_cls: type[BaseSettings],
+        init_settings: PydanticBaseSettingsSource,
+        env_settings: PydanticBaseSettingsSource,
+        dotenv_settings: PydanticBaseSettingsSource,
+        file_secret_settings: PydanticBaseSettingsSource,
+    ) -> tuple[PydanticBaseSettingsSource]:
+        return (
+            init_settings,
+            env_settings,
+            YamlConfigSettingsSource(settings_cls),
+        )
+
     @computed_field
     @property
-    def password(self) -> str:
-        return keyring.get_password(get_app_name(), self.username)
+    def password(self) -> str | None:
+        try:
+            return keyring.get_password(get_app_name(), self.username)
+        except NoKeyringError:
+            return None
 
     @password.setter
     def password(self, value: str) -> None:
@@ -66,8 +92,4 @@ class Settings(BaseSettings):
 
 def read() -> Settings:
     """Read the config."""
-    fpath = Settings.model_config["yaml_file"]
-    if not os.path.isfile(fpath):
-        return Settings()
-    with open(fpath) as f:
-        return Settings.model_validate(yaml.safe_load(f))
+    return Settings()
